Struct imf::IMF

source ·
pub struct IMF {
    pub version: u8,
    pub colors: BTreeMap<i32, (u8, u8, u8)>,
    pub width: usize,
    pub height: usize,
    pub map: Vec<i32>,
}
Stores the version, colors, width, height and content of an Integer Media File.

Fields

version: u8colors: BTreeMap<i32, (u8, u8, u8)>width: usizeheight: usizemap: Vec<i32>

Implementations

source

impl IMF

source

pub fn default() -> IMF

Returns an IMF filled with default values.

source

pub fn new(path: &str) -> Result<IMF, String>

Creates new IMF from file located at filepath. If you want to create a new one from existing variables, declare it like this:

use imf::IMF;

//assuming that all variables already exist
let imf = IMF {
    version,
    colors,
    width,
    height,
    map
};
source

pub fn get_xy(&self, x: usize, y: usize) -> Option<i32>

Returns number found at coordinates within IMF. See IMF::set_xy

Arguments
  • x - The X coordinate
  • y - The Y coordinate
Example
 use imf::IMF;
 //example.imf:
 //1,0,1,5,
 //4,7,3,3,
 //9,2,5,6,
 //0,5,8,2

 let mut imf = IMF::new("example.imf").unwrap();
 let n = imf.get_xy(1,1).unwrap();

 // n == 7
source

pub fn set_xy(&mut self, x: usize, y: usize, i: i32) -> bool

Sets number at coordinates within IMF to the number specified. See IMF::get_xy

Arguments
  • x - The X coordinate
  • y - The Y coordinate
  • i - What the number will be set to
Example
 use imf::IMF;

 let mut imf = IMF::new("example.imf").unwrap();
 imf.set_xy(2,2,5);

 // imf.get_xy(2,2) == 5
source

pub fn xy2i(&self, x: usize, y: usize) -> usize

Converts XY coordinates to an index. This does not check to see if anything exists at that index. See IMF::i2xy

Example
use imf::IMF;
//example.imf:
//1,0,1,5,
//4,7,3,3,
//9,2,5,6,
//0,5,8,2

let imf = IMF::new("example.imf").unwrap();
let n = imf.xy2i(2,2);

// n == 10
source

pub fn i2xy(&self, i: usize) -> Option<(usize, usize)>

Converts index to XY coordinates. See IMF::xy2i

Example
use imf::IMF;
//example.imf:
//1,0,1,5,
//4,7,3,3,
//9,2,5,6,
//0,5,8,2

let imf = IMF::new("example.imf").unwrap();
let n = imf.xy2i(2,2);
let m = imf.i2xy(10);

// n == m
source

pub fn write(&self, path: &str) -> Result<(), String>

Writes IMF to given filepath in .imf form